@@ -386,6 +386,19 @@ class RundeckJobs(object):
             # zx.run_shell_print(f"cd {config_dir_location} && \
             # terraform destroy -input=false -auto-approve")
             self.run_command(["terraform", "destroy", "-input=false", "-auto-approve"], cwd=config_dir_location,
-                             shell=True)
-            self.terraform_cloud_workspace(deployment_action, fqdn, datacenter, organization, terraform_cloud_token,
-                                           auto_apply, execution_mode, deployment_environment, terraform_code_dir)
+                             check=True)
+            pg_creds = vault_client.secrets.kv.read_secret_version(
+                path=f'tenant/devops/{project_name}/terraform-pgsql')['data']['data']
+            self.terraform_cloud_workspace(pg_user=pg_creds['user'],
+                                           pg_password=pg_creds['password'],
+                                           pg_ip=pg_creds['ip'],
+                                           pg_port=pg_creds['port'],
+                                           pg_db=pg_creds['dbname'],
+                                           fqdn=fqdn, organization=organization,
+                                           datacenter=datacenter,
+                                           tag_names=os.environ.get(
+                                               'RD_OPTION_TAG_NAMES'),
+                                           with_vcs_repo=os.environ.get(
+                                               'RD_OPTION_WITH_VCS_REPO'),
+                                           execution_mode=execution_mode, deployment_environment=deployment_environment,
+                                           deployment_action=deployment_action)
